<?php

namespace SGalinski\SgNews\UserFunction;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Core\SingletonInterface;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Domain\Model\FrontendUser;
use TYPO3\CMS\Extbase\Domain\Repository\FrontendUserRepository;
use TYPO3\CMS\Extbase\Object\ObjectManager;

/**
 * This class contains the methods, for adding additional mail recipients to the sg_comments TypoScript.
 */
class AddAdditionalMailRecipients implements SingletonInterface {
	/**
	 * @var \TYPO3\CMS\Frontend\ContentObject\ContentObjectRenderer
	 */
	public $cObj;

	/**
	 * Adds the news authors to the additional mail recipients.
	 *
	 * @return string
	 * @throws \InvalidArgumentException
	 */
	public function addAdditionalMailRecipients(): string {
		$newsAuthorUid = (int) $this->cObj->data['tx_sgnews_author'];
		if ($newsAuthorUid > 0) {
			/** @var ObjectManager $objectManager */
			$objectManager = GeneralUtility::makeInstance(ObjectManager::class);
			/** @var FrontendUserRepository $frontendUserRepository */
			$frontendUserRepository = $objectManager->get(FrontendUserRepository::class);
			/** @var FrontendUser $frontendUser */
			$frontendUser = $frontendUserRepository->findByUid($newsAuthorUid);
			if ($frontendUser) {
				$email = $frontendUser->getEmail();
				if (!empty($email)) {
					return $email;
				}
			}
		}

		$authorEmail = $this->cObj->data['author_email'];
		if (empty($authorEmail)) {
			return '';
		}

		return $authorEmail;
	}
}
